==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/SDXINTEGRATIONCONFIGPKID_Type.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for SDXINTEGRATIONCONFIGPKID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="SDXINTEGRATIONCONFIGPKID_Type">
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element name="SDXINTEGRATIONCONFIGPK" type="{http://www.openapplications.org/oagis_segments}QUANTITY"/>
 *         <element name="DESCRIPTION" type="{http://schemas.datastream.net/MP_fields}CODE255_Type" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SDXINTEGRATIONCONFIGPKID_Type", propOrder = {
    "sdxintegrationconfigpk",
    "description"
})
public class SDXINTEGRATIONCONFIGPKID_Type {

    @XmlElement(name = "SDXINTEGRATIONCONFIGPK", required = true)
    protected QUANTITY sdxintegrationconfigpk;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the sdxintegrationconfigpk property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSDXINTEGRATIONCONFIGPK() {
        return sdxintegrationconfigpk;
    }

    /**
     * Sets the value of the sdxintegrationconfigpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSDXINTEGRATIONCONFIGPK(QUANTITY value) {
        this.sdxintegrationconfigpk = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/SDXINTEGRATIONCONFIGPKID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for SDXINTEGRATIONCONFIGPKID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SDXINTEGRATIONCONFIGPKID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="SDXINTEGRATIONCONFIGPK" type="{http://www.openapplications.org/oagis_segments}QUANTITY"/>
 *         &lt;element name="DESCRIPTION" type="{http://schemas.datastream.net/MP_fields}CODE255_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SDXINTEGRATIONCONFIGPKID_Type", propOrder = {
    "sdxintegrationconfigpk",
    "description"
})
public class SDXINTEGRATIONCONFIGPKID_Type {

    @XmlElement(name = "SDXINTEGRATIONCONFIGPK", required = true)
    protected QUANTITY sdxintegrationconfigpk;
    @XmlElement(name = "DESCRIPTION")
    protected String description;

    /**
     * Gets the value of the sdxintegrationconfigpk property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getSDXINTEGRATIONCONFIGPK() {
        return sdxintegrationconfigpk;
    }

    /**
     * Sets the value of the sdxintegrationconfigpk property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setSDXINTEGRATIONCONFIGPK(QUANTITY value) {
        this.sdxintegrationconfigpk = value;
    }

    /**
     * Gets the value of the description property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDESCRIPTION() {
        return description;
    }

    /**
     * Sets the value of the description property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDESCRIPTION(String value) {
        this.description = value;
    }

}
